# Task: Parse HTML Table

Extract table data from an HTML page and write it as CSV.

## Requirements

1. Read `workspace/page.html`.
2. Find the `<table>` element and extract all rows.
3. The first row (in `<thead>`) contains headers.
4. Data rows are in `<tbody>`.
5. Write the data as a CSV file to `workspace/table_data.csv` with headers as the first row.

## Output

Save the extracted table data to `workspace/table_data.csv`.
